@@ -2,11 +2,11 @@
  *
  * compat.c
  *	  Provides a couple of useful string utility functions adapted
- *	  from the backend code, which are not publicly exposed. They're
- *	  unlikely to change but it would be worth keeping an eye on them
- *	  for any fixes/improvements
+ *	  from the backend code, which are not publicly exposed in all
+ *    supported PostgreSQL versions. They're unlikely to change but
+ *    it would be worth keeping an eye on them for any fixes/improvements.
  *
- * Copyright (c) 2ndQuadrant, 2010-2017
+ * Copyright (c) 2ndQuadrant, 2010-2018
  *
  * Portions Copyright (c) 1996-2013, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
@@ -104,4 +104,3 @@ appendShellString(PQExpBuffer buf, const char *str)
 
 	appendPQExpBufferChar(buf, '\'');
 }
-
