@@ -1,6 +1,6 @@
 /*
  * errcode.h
- * Copyright (c) 2ndQuadrant, 2010-2017
+ * Copyright (c) 2ndQuadrant, 2010-2018
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,21 +14,23 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
  */
 
 #ifndef _ERRCODE_H_
 #define _ERRCODE_H_
 
-/* Exit return code */
+/* Exit return codes */
 
 #define SUCCESS 0
 #define ERR_BAD_CONFIG 1
 #define ERR_BAD_RSYNC 2
+#define ERR_BAD_PIDFILE 3
 #define ERR_NO_RESTART 4
-#define ERR_DB_CON 6
+#define ERR_LOCAL_COMMAND 5
+#define ERR_DB_CONN 6
 #define ERR_DB_QUERY 7
-#define ERR_PROMOTED 8
+#define ERR_PROMOTION_FAIL 8
+#define ERR_MONITORING_TIMEOUT 9
 #define ERR_STR_OVERFLOW 10
 #define ERR_FAILOVER_FAIL 11
 #define ERR_BAD_SSH 12
@@ -40,6 +42,7 @@
 #define ERR_SWITCHOVER_FAIL 18
 #define ERR_BARMAN 19
 #define ERR_REGISTRATION_SYNC 20
+#define ERR_OUT_OF_MEMORY 21
+#define ERR_SWITCHOVER_INCOMPLETE 22
 
-
-#endif   /* _ERRCODE_H_ */
+#endif							/* _ERRCODE_H_ */
