@@ -1,8 +1,6 @@
 /*
  * log.c - Logging methods
- * Copyright (c) 2ndQuadrant, 2010-2017
- *
- * This module is a set of methods for logging (currently only syslog)
+ * Copyright (c) 2ndQuadrant, 2010-2018
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
  */
 
 #include "repmgr.h"
@@ -40,14 +37,16 @@
 /* #define REPMGR_DEBUG */
 
 static int	detect_log_facility(const char *facility);
-static void _stderr_log_with_level(const char *level_name, int level, const char *fmt, va_list ap)
+static void
+_stderr_log_with_level(const char *level_name, int level, const char *fmt, va_list ap)
 __attribute__((format(PG_PRINTF_ATTRIBUTE, 3, 0)));
 
 int			log_type = REPMGR_STDERR;
 int			log_level = LOG_NOTICE;
-int			last_log_level = LOG_NOTICE;
+int			last_log_level = LOG_INFO;
 int			verbose_logging = false;
 int			terse_logging = false;
+
 /*
  * Global variable to be set by the main application to ensure any log output
  * emitted before logger_init is called, is output in the correct format
@@ -55,7 +54,7 @@ int			terse_logging = false;
 int			logger_output_mode = OM_DAEMON;
 
 extern void
-stderr_log_with_level(const char *level_name, int level, const char *fmt, ...)
+stderr_log_with_level(const char *level_name, int level, const char *fmt,...)
 {
 	va_list		arglist;
 
@@ -70,8 +69,8 @@ _stderr_log_with_level(const char *level_name, int level, const char *fmt, va_li
 	char		buf[100];
 
 	/*
-	 * Store the requested level so that if there's a subsequent
-	 * log_hint(), we can suppress that if appropriate.
+	 * Store the requested level so that if there's a subsequent log_hint() or
+	 * log_detail(), we can suppress that if appropriate.
 	 */
 	last_log_level = level;
 
@@ -83,6 +82,7 @@ _stderr_log_with_level(const char *level_name, int level, const char *fmt, va_li
 		{
 			time_t		t;
 			struct tm  *tm;
+
 			time(&t);
 			tm = localtime(&t);
 			strftime(buf, 100, "[%Y-%m-%d %H:%M:%S]", tm);
@@ -94,13 +94,13 @@ _stderr_log_with_level(const char *level_name, int level, const char *fmt, va_li
 		}
 
 		vfprintf(stderr, fmt, ap);
-
+		fprintf(stderr, "\n");
 		fflush(stderr);
 	}
 }
 
 void
-log_hint(const char *fmt, ...)
+log_hint(const char *fmt,...)
 {
 	va_list		ap;
 
@@ -114,7 +114,21 @@ log_hint(const char *fmt, ...)
 
 
 void
-log_verbose(int level, const char *fmt, ...)
+log_detail(const char *fmt,...)
+{
+	va_list		ap;
+
+	if (terse_logging == false)
+	{
+		va_start(ap, fmt);
+		_stderr_log_with_level("DETAIL", last_log_level, fmt, ap);
+		va_end(ap);
+	}
+}
+
+
+void
+log_verbose(int level, const char *fmt,...)
 {
 	va_list		ap;
 
@@ -122,7 +136,7 @@ log_verbose(int level, const char *fmt, ...)
 
 	if (verbose_logging == true)
 	{
-		switch(level)
+		switch (level)
 		{
 			case LOG_EMERG:
 				_stderr_log_with_level("EMERG", level, fmt, ap);
@@ -133,8 +147,8 @@ log_verbose(int level, const char *fmt, ...)
 			case LOG_CRIT:
 				_stderr_log_with_level("CRIT", level, fmt, ap);
 				break;
-			case LOG_ERR:
-				_stderr_log_with_level("ERR", level, fmt, ap);
+			case LOG_ERROR:
+				_stderr_log_with_level("ERROR", level, fmt, ap);
 				break;
 			case LOG_WARNING:
 				_stderr_log_with_level("WARNING", level, fmt, ap);
@@ -158,8 +172,8 @@ log_verbose(int level, const char *fmt, ...)
 bool
 logger_init(t_configuration_options *opts, const char *ident)
 {
-	char	   *level = opts->loglevel;
-	char	   *facility = opts->logfacility;
+	char	   *level = opts->log_level;
+	char	   *facility = opts->log_facility;
 
 	int			l;
 	int			f;
@@ -169,7 +183,7 @@ logger_init(t_configuration_options *opts, const char *ident)
 #endif
 
 #ifdef REPMGR_DEBUG
-	printf("Logger initialisation (Level: %s, Facility: %s)\n", level, facility);
+	printf("logger initialisation (Level: %s, Facility: %s)\n", level, facility);
 #endif
 
 	if (!ident)
@@ -181,18 +195,18 @@ logger_init(t_configuration_options *opts, const char *ident)
 	{
 		l = detect_log_level(level);
 #ifdef REPMGR_DEBUG
-		printf("Assigned level for logger: %d\n", l);
+		printf("assigned level for logger: %d\n", l);
 #endif
 
 		if (l >= 0)
 			log_level = l;
 		else
-			stderr_log_warning(_("Invalid log level \"%s\" (available values: DEBUG, INFO, NOTICE, WARNING, ERR, ALERT, CRIT or EMERG)\n"), level);
+			stderr_log_warning(_("invalid log level \"%s\" (available values: DEBUG, INFO, NOTICE, WARNING, ERR, ALERT, CRIT or EMERG)\n"), level);
 	}
 
 	/*
-	 * STDERR only logging requested - finish here without setting up any further
-	 * logging facility.
+	 * STDERR only logging requested - finish here without setting up any
+	 * further logging facility.
 	 */
 	if (logger_output_mode == OM_COMMAND_LINE)
 		return true;
@@ -202,19 +216,19 @@ logger_init(t_configuration_options *opts, const char *ident)
 
 		f = detect_log_facility(facility);
 #ifdef REPMGR_DEBUG
-		printf("Assigned facility for logger: %d\n", f);
+		printf("assigned facility for logger: %d\n", f);
 #endif
 
 		if (f == 0)
 		{
 			/* No syslog requested, just stderr */
 #ifdef REPMGR_DEBUG
-			printf(_("Use stderr for logging\n"));
+			printf(_("using stderr for logging\n"));
 #endif
 		}
 		else if (f == -1)
 		{
-			stderr_log_warning(_("Cannot detect log facility %s (use any of LOCAL0, LOCAL1, ..., LOCAL7, USER or STDERR)\n"), facility);
+			stderr_log_warning(_("cannot detect log facility %s (use any of LOCAL0, LOCAL1, ..., LOCAL7, USER or STDERR)\n"), facility);
 		}
 #ifdef HAVE_SYSLOG
 		else
@@ -232,40 +246,42 @@ logger_init(t_configuration_options *opts, const char *ident)
 		setlogmask(LOG_UPTO(log_level));
 		openlog(ident, LOG_CONS | LOG_PID | LOG_NDELAY, syslog_facility);
 
-		stderr_log_notice(_("Setup syslog (level: %s, facility: %s)\n"), level, facility);
+		stderr_log_notice(_("setup syslog (level: %s, facility: %s)\n"), level, facility);
 	}
 #endif
 
-	if (*opts->logfile)
+	if (*opts->log_file)
 	{
 		FILE	   *fd;
 
-		/* Check if we can write to the specified file before redirecting
-		 * stderr - if freopen() fails, stderr output will vanish into
-		 * the ether and the user won't know what's going on.
+		/*
+		 * Check if we can write to the specified file before redirecting
+		 * stderr - if freopen() fails, stderr output will vanish into the
+		 * ether and the user won't know what's going on.
 		 */
 
-		fd = fopen(opts->logfile, "a");
+		fd = fopen(opts->log_file, "a");
 		if (fd == NULL)
 		{
-			stderr_log_err(_("Unable to open specified logfile '%s' for writing: %s\n"), opts->logfile, strerror(errno));
-			stderr_log_err(_("Terminating\n"));
+			stderr_log_error(_("unable to open specified log file \"%s\" for writing: %s\n"),
+							 opts->log_file, strerror(errno));
+			stderr_log_error(_("Terminating\n"));
 			exit(ERR_BAD_CONFIG);
 		}
 		fclose(fd);
 
-		stderr_log_notice(_("Redirecting logging output to '%s'\n"), opts->logfile);
-		fd = freopen(opts->logfile, "a", stderr);
+		stderr_log_notice(_("redirecting logging output to \"%s\"\n"), opts->log_file);
+		fd = freopen(opts->log_file, "a", stderr);
 
 		/*
-		 * It's possible freopen() may still fail due to e.g. a race condition;
-		 * as it's not feasible to restore stderr after a failed freopen(),
-		 * we'll write to stdout as a last resort.
+		 * It's possible freopen() may still fail due to e.g. a race
+		 * condition; as it's not feasible to restore stderr after a failed
+		 * freopen(), we'll write to stdout as a last resort.
 		 */
 		if (fd == NULL)
 		{
-			printf(_("Unable to open specified logfile %s for writing: %s\n"), opts->logfile, strerror(errno));
-			printf(_("Terminating\n"));
+			printf(_("unable to open specified log file %s for writing: %s\n"), opts->log_file, strerror(errno));
+			printf(_("terminating\n"));
 			exit(ERR_BAD_CONFIG);
 		}
 	}
@@ -306,7 +322,8 @@ logger_set_verbose(void)
  * options and hints.
  */
 
-void logger_set_terse(void)
+void
+logger_set_terse(void)
 {
 	terse_logging = true;
 }
@@ -315,21 +332,21 @@ void logger_set_terse(void)
 int
 detect_log_level(const char *level)
 {
-	if (!strcmp(level, "DEBUG"))
+	if (!strcasecmp(level, "DEBUG"))
 		return LOG_DEBUG;
-	if (!strcmp(level, "INFO"))
+	if (!strcasecmp(level, "INFO"))
 		return LOG_INFO;
-	if (!strcmp(level, "NOTICE"))
+	if (!strcasecmp(level, "NOTICE"))
 		return LOG_NOTICE;
-	if (!strcmp(level, "WARNING"))
+	if (!strcasecmp(level, "WARNING"))
 		return LOG_WARNING;
-	if (!strcmp(level, "ERR"))
-		return LOG_ERR;
-	if (!strcmp(level, "ALERT"))
+	if (!strcasecmp(level, "ERROR"))
+		return LOG_ERROR;
+	if (!strcasecmp(level, "ALERT"))
 		return LOG_ALERT;
-	if (!strcmp(level, "CRIT"))
+	if (!strcasecmp(level, "CRIT"))
 		return LOG_CRIT;
-	if (!strcmp(level, "EMERG"))
+	if (!strcasecmp(level, "EMERG"))
 		return LOG_EMERG;
 
 	return -1;
